@@ -1,5 +1,5 @@
-confusionLabel <- function(model = NULL, obs = NULL, pred = NULL, thresh, verbosity = 2, na.rm = FALSE, rm.dup = FALSE) {
-  # version 1.6 (16 May 2022)
+confusionLabel <- function(model = NULL, obs = NULL, pred = NULL, thresh, interval = interval, quant = quant, verbosity = 2, na.rm = FALSE, rm.dup = FALSE) {
+  # version 1.7 (14 Jun 2022)
   
   pred_in <- pred  # in case input is raster, so final reclass is also raster
   
@@ -7,6 +7,10 @@ confusionLabel <- function(model = NULL, obs = NULL, pred = NULL, thresh, verbos
   obs <- obspred[ , "obs"]
   pred <- obspred[ , "pred"]
   
+  if (!(is.numeric(thresh) || thresh %in% modEvAmethods("getThreshold")))
+    stop("'thresh' must be either a numeric value between 0 and 1, or one of the options obtained with modEvAmethods('getThreshold')")
+  if (thresh %in% modEvAmethods("getThreshold"))  thresh <- getThreshold(obs = obs, pred = pred, threshMethod = thresh, interval = interval, quant = quant, na.rm = na.rm)
+  
   res <- rep("", length(obs))
   res[pred >= thresh & obs == 1] <- "TruePos"
   res[pred < thresh & obs == 0] <- "TrueNeg"
